import { useAuthorizationCache } from '@graphpolaris/shared/lib/data-access';
import { useAuthorization } from '@graphpolaris/shared/lib/data-access/authorization';
import { domain } from '../../environments/variables';
import styled from 'styled-components';

const Wrapper = styled.div`
  font-family: Arial, serif;
  position: absolute;
  left: 0;
  top: 0;
  // Cover the screen
  width: 100vw;
  height: 100vh;

  display: flex;
  justify-content: center;
  align-items: center;
`;

const Background = styled.div`
  position: absolute;

  width: 100%;
  height: 100%;

  z-index: 1;

  // Blur
  background: rgba(
    0,
    0,
    0,
    0.4
  ); // Make sure this color has an opacity of less than 1
  backdrop-filter: blur(8px); // This be the blur
`;

const Content = styled.div`
  background-color: white;
  box-shadow: 0 3px 10px rgb(0 0 0 / 0.2);
  padding: 2em;
  z-index: 2;
  border-radius: 8px;

  display: flex;
  flex-direction: column;
  gap: 1em;
  align-items: center;
  justify-content: center;

  // Give children 0 padding and margin
  * {
    display: flex;
    margin: 0;
    padding: 0;

    // Same width flexbox items
    flex: 1 1 0;

    max-height: 3em;

    &:hover {
      cursor: pointer;
    }
  }
`;

const LoginScreen = () => {
  const { SetAccessToken } = useAuthorization(domain);

  const openSignInWindow = (url: string) => {
    // remove any existing event listeners
    window.removeEventListener('auth_message', receiveMessage);

    // window features
    const strWindowFeatures =
      'toolbar=no, menubar=no, width=600, height=700, top=100, left=100';

    window.open(url, 'Google Oauth', strWindowFeatures);

    // add the listener for receiving a message from the popup
    window.addEventListener(
      'auth_message',
      (event) => receiveMessage(event),
      false
    );
  };

  const receiveMessage = (event: any) => {
    // Do we trust the sender of this message? (might be
    // different from what we originally opened)
    if (window.location.hostname !== event.detail.origin) {
      return;
    }
    console.log(event.detail.token);

    // Set access token
    SetAccessToken(event.detail.token);
  };

  return (
    <Wrapper>
      <Background></Background>
      <Content>
        <h1 className="pointer-events-none">Sign In</h1>
        <img
          onClick={() =>
            openSignInWindow(
              'https://api.graphpolaris.com/user/sign-in?provider=1'
            )
          }
          src="assets/login-screen/google.png"
          alt="sign up with google"
        />
        <img
          onClick={() =>
            openSignInWindow(
              'https://api.graphpolaris.com/user/sign-in?provider=2'
            )
          }
          src="assets/login-screen/github.png"
          alt="sign up with github"
        />
        <p
          onClick={() =>
            openSignInWindow('https://api.graphpolaris.com/user/create_free/')
          }
        >
          Developer
        </p>
      </Content>
    </Wrapper>
  );
};

export default LoginScreen;
