import { createSlice, PayloadAction } from '@reduxjs/toolkit';
import type { RootState } from './store';
import { useIsAuthorizedState } from '../authorization';



// Define the initial state using that type
export const initialState: useIsAuthorizedState = {
  authorized: false,
  accessToken: '',
};

export const authSlice = createSlice({
  name: 'auth',
  // `createSlice` will infer the state type from the `initialState` argument
  initialState,
  reducers: {
    updateAccessToken(state, action: PayloadAction<string>) {
      state.accessToken = action.payload;
    },
    authorized(state, action: PayloadAction<useIsAuthorizedState>) {
      state.authorized = action.payload.authorized;
      state.accessToken = action.payload.accessToken;
      state.sessionID = action.payload.sessionID;
      state.userID = action.payload.userID;
    }
  },
});

export const {
  updateAccessToken, authorized
} = authSlice.actions;

// Other code such as selectors can use the imported `RootState` type
export const authState = (state: RootState) => state.auth;

export default authSlice.reducer;
