import React from 'react';
import { ComponentStory, Meta } from '@storybook/react';
import { NodeLinkVis } from './nodelinkvis';

import {
  assignNewGraphQueryResult,
  colorPaletteConfigSlice,
  graphQueryResultSlice,
  resetGraphQueryResults,
  store,
} from '../../data-access/store';
import { configureStore } from '@reduxjs/toolkit';
import { Provider } from 'react-redux';
import { GraphPolarisThemeProvider } from '../../data-access/theme';
import {
  big2ndChamberQueryResult,
  smallFlightsQueryResults,
} from '../../mock-data';

const Component: Meta<typeof NodeLinkVis> = {
  /* 👇 The title prop is optional.
   * See https://storybook.js.org/docs/react/configure/overview#configure-story-loading
   * to learn how to generate automatic titles
   */
  title: 'Components/Visualizations/NodeLinkVis',
  component: NodeLinkVis,
  decorators: [
    (story) => (
      <Provider store={Mockstore}>
        <GraphPolarisThemeProvider>
          <div
            style={{
              width: '100%',
              height: '100vh',
            }}
          >
            {story()}
          </div>
        </GraphPolarisThemeProvider>
      </Provider>
    ),
  ],
};

const Mockstore = configureStore({
  reducer: {
    colorPaletteConfig: colorPaletteConfigSlice.reducer,
    graphQueryResult: graphQueryResultSlice.reducer,
  },
});

const Template: ComponentStory<typeof NodeLinkVis> = (args) => (
  <NodeLinkVis {...args} />
);

export const TestWithData = Template.bind({});
TestWithData.args = {
  loading: false,
};
TestWithData.play = async () => {
  const dispatch = Mockstore.dispatch;
  dispatch(
    assignNewGraphQueryResult({
      nodes: [
        { id: 'agent/007', attributes: { name: 'Daniel Craig' } },
        { id: 'villain', attributes: { name: 'Le Chiffre' } },
      ],
      edges: [
        { from: 'agent/007', to: 'villain', attributes: { name: 'Escape' } },
      ],
    })
  );
};

export const TestWithNoData = Template.bind({});
TestWithNoData.args = {
  loading: false,
};
TestWithNoData.play = async () => {
  const dispatch = Mockstore.dispatch;
  dispatch(
    assignNewGraphQueryResult({
      nodes: [],
      edges: [],
    })
  );
};

export const TestWithBig2ndChamber = Template.bind({});
TestWithBig2ndChamber.args = {
  loading: false,
};
TestWithBig2ndChamber.play = async () => {
  const dispatch = Mockstore.dispatch;
  dispatch(assignNewGraphQueryResult(big2ndChamberQueryResult));
};

export const TestWithSmallFlights = Template.bind({});
TestWithSmallFlights.args = {
  loading: false,
};
TestWithSmallFlights.play = async () => {
  const dispatch = Mockstore.dispatch;
  dispatch(assignNewGraphQueryResult(smallFlightsQueryResults));
};

// export const Loading = Template.bind({});
// Loading.args = {
//   loading: true,
// };
//
// export const Empty = Template.bind({});
// Empty.args = {
//   // Shaping the stories through args composition.
//   // Inherited data coming from the Loading story.
//   ...Loading.args,
//   loading: false,
// };
// Empty.play = async () => {
//   const dispatch = store.dispatch;
//   dispatch(resetGraphQueryResults());
// };

export default Component;
